@@ -17,7 +17,7 @@ document.getElementById("Contents").innerHTML='\
     <li><input type="checkbox" id="0702"><label for="0702">Kommandoer</label><ul>\
     <li><a target="_top" href="nb/text/sbasic/shared/01020300.html">Using Procedures and Functions</a></li>\
     <li><a target="_top" href="nb/text/sbasic/shared/01020500.html">Libraries, Modules and Dialogs</a></li>\
-    <li><input type="checkbox" id="070202"><label for="070202">Functions, Statements, and Operators</label><ul>\
+    <li><input type="checkbox" id="070202"><label for="070202">Funksjoner, uttrykk og operatorer</label><ul>\
     <li><a target="_top" href="nb/text/sbasic/shared/03010000.html">Screen I/O Functions</a></li>\
     <li><a target="_top" href="nb/text/sbasic/shared/03020000.html">File I/O Functions</a></li>\
     <li><a target="_top" href="nb/text/sbasic/shared/03030000.html">Date and Time Functions</a></li>\
@@ -271,7 +271,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nb/text/sbasic/shared/03070400.html">"/" Operator</a></li>\
     <li><a target="_top" href="nb/text/sbasic/shared/03070500.html">"^" Operator</a></li>\
 			</ul></li>\
-    <li><input type="checkbox" id="070205"><label for="070205">Advanced Basic Libraries</label><ul>\
+    <li><input type="checkbox" id="070205"><label for="070205">Avanserte Basic-bibliotek</label><ul>\
     <li><a target="_top" href="nb/text/sbasic/shared/03/lib_tools.html">Tools Library</a></li>\
     <li><a target="_top" href="nb/text/sbasic/shared/03/lib_depot.html">DEPOT Library</a></li>\
     <li><a target="_top" href="nb/text/sbasic/shared/03/lib_euro.html">EURO Library</a></li>\
@@ -419,7 +419,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nb/text/scalc/guide/datapilot_tipps.html">Selecting Pivot Table Output Ranges</a></li>\
     <li><a target="_top" href="nb/text/scalc/guide/datapilot_updatetable.html">Oppdatere dataveivisertabeller</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="08091"><label for="08091">Pivot Chart</label><ul>\
+    <li><input type="checkbox" id="08091"><label for="08091">Pivotdiagram</label><ul>\
     <li><a target="_top" href="nb/text/scalc/guide/pivotchart.html">Pivot Chart</a></li>\
     <li><a target="_top" href="nb/text/scalc/guide/pivotchart_create.html">Creating Pivot Charts</a></li>\
     <li><a target="_top" href="nb/text/scalc/guide/pivotchart_edit.html">Editing Pivot Charts</a></li>\
@@ -567,7 +567,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nb/text/shared/guide/textmode_change.html">Bytte mellom innsettingstilstand og overskrivingstilstand</a></li>\
     <li><a target="_top" href="nb/text/shared/guide/floating_toolbar.html">Bruke verktøylinjer</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="10071"><label for="10071">Digital Signatures</label><ul>\
+    <li><input type="checkbox" id="10071"><label for="10071">Digitale signaturer</label><ul>\
     <li><a target="_top" href="nb/text/shared/guide/digital_signatures.html">Om digitale signaturer</a></li>\
     <li><a target="_top" href="nb/text/shared/guide/digitalsign_send.html">Legge til digitale signaturer</a></li>\
     <li><a target="_top" href="nb/text/shared/01/digitalsignaturespdf.html">Digital Signature in PDF Export</a></li>\
@@ -860,7 +860,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="nb/text/swriter/main0105.html">Format</a></li>\
     <li><a target="_top" href="nb/text/swriter/main0115.html">Stiler</a></li>\
     <li><a target="_top" href="nb/text/swriter/main0110.html">Tabell</a></li>\
-    <li><a target="_top" href="nb/text/swriter/main0120.html">Form Menu</a></li>\
+    <li><a target="_top" href="nb/text/swriter/main0120.html">Skjemameny</a></li>\
     <li><a target="_top" href="nb/text/swriter/main0106.html">Verktøy</a></li>\
     <li><a target="_top" href="nb/text/swriter/main0107.html">Vindu</a></li>\
     <li><a target="_top" href="nb/text/shared/main0108.html">Hjelp</a></li>\
